@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::App::Command::config;
-$Footprintless::App::Command::config::VERSION = '1.20';
+$Footprintless::App::Command::config::VERSION = '1.21';
 # ABSTRACT: Prints the config at the coordinate.
 # PODNAME: Footprintless::App::Command::config
 
@@ -60,7 +60,7 @@ sub execute {
     if ( $format =~ /^dumper([0-3])?$/ ) {
         require Data::Dumper;
         my $indent = defined($1) ? $1 : 1;
-        $string = Data::Dumper->new( [$config] )->Indent($indent)->Dump();
+        $string = Data::Dumper->new( [$config] )->Indent($indent)->Sortkeys(1)->Dump();
     }
     elsif ( $format eq 'properties' ) {
         my $properties = _entity_to_properties($config);
@@ -72,7 +72,7 @@ sub execute {
         if ( !defined($1) || $1 == 1 || $1 == 3 ) {
             $json->pretty();
         }
-        if ( $1 == 2 || $1 == 3 ) {
+        if ( !defined($1) || $1 == 2 || $1 == 3 ) {
             $json->canonical(1);
         }
         $string = $json->encode($config);
@@ -108,7 +108,7 @@ Footprintless::App::Command::config - Prints the config at the coordinate.
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 SYNOPSIS
 
@@ -125,8 +125,8 @@ Prints out the config at the specified coordinate.  The supported formats are:
     dumper0     Perl Data::Dumper without newlines
     dumper1     Perl Data::Dumper with fixed indentation (2 spaces)
     dumper2     Perl Data::Dumper with dynamic indent
-    dumper3     Perl Data::Dumper with dynamic indant and annotations
-    json        Same as json1
+    dumper3     Perl Data::Dumper with dynamic indent and annotations
+    json        Same as json3
     json0       Compact JSON
     json1       Pretty printed JSON
     json2       JSON with canonically sorted keys
